@@ -24,11 +24,13 @@ const (
 	OptionExclude         = "exclude"
 	OptionServerJSON      = "server-json"
 	OptionSource          = "source"
+	OptionInterface       = "interface"
 	OptionTimeout         = "timeout"
 	OptionChunks          = "chunks"
 	OptionUploadSize      = "upload-size"
 	OptionDuration        = "duration"
 	OptionSecure          = "secure"
+	OptionCACert          = "ca-cert"
 	OptionSkipCertVerify  = "skip-cert-verify"
 	OptionNoPreAllocate   = "no-pre-allocate"
 	OptionVersion         = "version"
